import { __extends, __rest, __assign } from './../../external/tslib/tslib.es6.js';
import classnames from 'classnames';
import isEmpty from './../../external/lodash/fp/isEmpty.js';
import * as React from 'react';
import { parseMetadata } from '@highlight-ui/utils-commons';
import styles from './DropdownMenu.module.scss.js';

var DropdownMenu = function (_super) {
  __extends(DropdownMenu, _super);

  function DropdownMenu(props) {
    var _this = _super.call(this, props) || this;

    _this.controlledComponent = true;

    _this.dropdownCurrentRef = function () {
      return _this.dropdownRef.current || {};
    };

    _this._handleClickOutside = function (event) {
      var _a = _this,
          open = _a.open,
          onToggleCallback = _a.onToggleCallback,
          props = _a.props;

      var dropdownRef = _this.dropdownCurrentRef();

      if (props.closeOnClickAnywhere && open) {
        if (typeof onToggleCallback === 'function') onToggleCallback();
      } else if (open && !isEmpty(dropdownRef) && !dropdownRef.contains(event.target)) {
        if (typeof onToggleCallback === 'function') onToggleCallback();
      }
    };

    _this.handleRequestToChange = function () {
      var controlledComponent = _this.controlledComponent;
      var _a = _this.props,
          onRequestToChange = _a.onRequestToChange,
          disabled = _a.disabled; // Should be not disabled, controlled and have a event handler

      if (!disabled && controlledComponent && typeof onRequestToChange === 'function') {
        onRequestToChange();
      }
    };

    _this.handleOpen = function () {
      var _a = _this.props,
          onChange = _a.onChange,
          onOpen = _a.onOpen,
          disabled = _a.disabled;
      if (disabled) return;

      _this.setState({
        open: true
      }, function () {
        if (typeof onOpen === 'function') onOpen();
        if (typeof onChange === 'function') onChange();
      });
    };

    _this.handleClose = function () {
      var _a = _this.props,
          onChange = _a.onChange,
          onClose = _a.onClose,
          disabled = _a.disabled;
      if (disabled) return;

      _this.setState({
        open: false
      }, function () {
        if (typeof onClose === 'function') onClose();
        if (typeof onChange === 'function') onChange();
      });
    };

    _this.handleToggle = function () {
      var open = _this.state.open;
      var method = open ? 'handleClose' : 'handleOpen';

      _this[method]();
    };

    var open = props.open,
        defaultValue = props.defaultValue;
    _this.dropdownRef = /*#__PURE__*/React.createRef();
    _this.state = {
      open: false,
      width: 0
    }; // We use a internal state to control whether the dropdown is open or not,
    // but if the user set a initial prop, then, this prop will control the state

    if (open === null) {
      _this.controlledComponent = false;
      if (defaultValue) _this.state = {
        open: true,
        width: 0
      };
    }

    return _this;
  }

  DropdownMenu.prototype.componentDidMount = function () {
    this.setState({
      width: this.dropdownCurrentRef().offsetWidth
    });
  };

  DropdownMenu.prototype.componentDidUpdate = function () {
    if (this.open) document.addEventListener('click', this._handleClickOutside);else document.removeEventListener('click', this._handleClickOutside);
  };

  DropdownMenu.prototype.componentWillUnmount = function () {
    document.removeEventListener('click', this._handleClickOutside);
  };

  Object.defineProperty(DropdownMenu.prototype, "open", {
    get: function () {
      var _a = this,
          props = _a.props,
          state = _a.state,
          controlledComponent = _a.controlledComponent;

      if (controlledComponent) return props.open || false;
      return state.open;
    },
    enumerable: false,
    configurable: true
  });
  Object.defineProperty(DropdownMenu.prototype, "onToggleCallback", {
    get: function () {
      var onRequestToChange = this.props.onRequestToChange;
      return this.controlledComponent ? onRequestToChange : this.handleToggle;
    },
    enumerable: false,
    configurable: true
  });

  DropdownMenu.prototype.render = function () {
    var _this = this;

    var _a = this.props,
        children = _a.children,
        className = _a.className;
    _a.onRequestToChange;
    _a.closeOnClickAnywhere;
    _a.onOpen;
    _a.defaultValue;

    var metadata = _a.metadata,
        remainingProps = __rest(_a, ["children", "className", "onRequestToChange", "closeOnClickAnywhere", "onOpen", "defaultValue", "metadata"]);

    var width = this.state.width;
    var containerClassName = classnames(styles.dropdownContainer, className);
    return /*#__PURE__*/React.createElement("div", __assign({}, remainingProps, parseMetadata(metadata), {
      className: containerClassName,
      ref: this.dropdownRef
    }), React.Children.map(children, function (child) {
      if ( /*#__PURE__*/React.isValidElement(child)) {
        return /*#__PURE__*/React.cloneElement(child, {
          open: _this.open,
          onToggle: _this.onToggleCallback,
          containerWidth: width
        });
      }

      return null;
    }));
  };

  DropdownMenu.defaultProps = {
    disabled: false,
    open: null,
    defaultValue: false
  };
  return DropdownMenu;
}(React.PureComponent);

export { DropdownMenu as default };
//# sourceMappingURL=DropdownMenu.js.map
