import { __extends, __rest, __assign } from './../../external/tslib/tslib.es6.js';
import * as React from 'react';
import classnames from 'classnames';
import camelCase from './../../external/lodash/fp/camelCase.js';
import { parseMetadata } from '@highlight-ui/utils-commons';
import { DropdownMenuHeader } from '../DropdownMenuHeader/DropdownMenuHeader.js';
import styles from './DropdownMenuList.module.scss.js';
import { calculateTop, calculateLeft } from './dropdownMenuListUtils.js';

var DropdownMenuList = function (_super) {
  __extends(DropdownMenuList, _super);

  function DropdownMenuList(props) {
    var _this = _super.call(this, props) || this;

    _this.dropdownListRef = /*#__PURE__*/React.createRef();
    return _this;
  }

  DropdownMenuList.prototype.componentDidUpdate = function () {
    var _a = this,
        props = _a.props,
        dropdownListRef = _a.dropdownListRef;

    var containerWidth = props.containerWidth,
        direction = props.direction;
    var currRef = dropdownListRef.current;

    if (direction === 'center' && currRef && containerWidth) {
      var dropdownListWidth = currRef.offsetWidth;
      var left = calculateLeft(containerWidth, dropdownListWidth);
      currRef.style.left = left + "px";
    }

    if ((direction === 'top-left' || direction === 'top-right') && currRef) {
      var top_1 = calculateTop(currRef);
      currRef.style.top = "-" + (top_1 + 5) + "px";
    }
  };

  DropdownMenuList.prototype.render = function () {
    var _a = this.props,
        open = _a.open;
    _a.containerWidth;

    var className = _a.className,
        children = _a.children,
        onToggle = _a.onToggle,
        preventToCloseOnClick = _a.preventToCloseOnClick,
        direction = _a.direction,
        metadata = _a.metadata,
        remainingProps = __rest(_a, ["open", "containerWidth", "className", "children", "onToggle", "preventToCloseOnClick", "direction", "metadata"]);

    if (!open) return null;
    var containerClassName = classnames(styles.dropdownListContainer, direction ? styles[camelCase(direction)] : undefined, className);
    return /*#__PURE__*/React.createElement("div", __assign({}, remainingProps, parseMetadata(metadata), {
      className: containerClassName,
      ref: this.dropdownListRef
    }), Boolean(this.props.title) && /*#__PURE__*/React.createElement(DropdownMenuHeader, {
      title: this.props.title
    }), React.Children.map(children, function (child) {
      return /*#__PURE__*/React.isValidElement(child) ? /*#__PURE__*/React.cloneElement(child, {
        onClick: child && child.props && child.props.onClick ? child.props.onClick : onToggle,
        preventToCloseOnClick: preventToCloseOnClick
      }) : null;
    }));
  }; // eslint-disable-next-line react/static-property-placement


  DropdownMenuList.defaultProps = {
    open: false,
    preventToCloseOnClick: false,
    direction: 'bottom-right',
    containerWidth: 0,
    className: null,
    onToggle: null
  };
  return DropdownMenuList;
}(React.Component);

export { DropdownMenuList };
//# sourceMappingURL=DropdownMenuList.js.map
